@@ -1,4 +1,5 @@
 import builtins
+import sys
 import warnings
 from enum import Enum
 from pathlib import Path
@@ -41,6 +42,9 @@ _main.__doc__ = typer.style(
     (_main.__doc__ or "").format(version=__version__), fg="bright_yellow"
 )
 
+SYNTAX_THME = "monokai"
+SYNTAX_BACKGROUND = "black"
+
 
 class Format(str, Enum):
     """Valid manifest file formats."""
@@ -64,7 +68,10 @@ def _pprint_formatted(string, format: Format = Format.yaml):  # pragma: no cover
     from rich.console import Console
     from rich.syntax import Syntax
 
-    Console().print(Syntax(string, format.value, theme="fruity"))
+    syntax = Syntax(
+        string, format.value, theme=SYNTAX_THME, background_color=SYNTAX_BACKGROUND
+    )
+    Console().print(syntax)
 
 
 def _pprint_exception(err: Exception):
@@ -309,9 +316,26 @@ def list(
             typer.echo(template.format(**r, ncontrib=ncontrib))
 
 
+def _fetch_all_manifests(doit: bool):
+    """Fetch all manifests and dump to "manifests" folder."""
+    if not doit:
+        return
+
+    from npe2._inspection import _fetch
+
+    dest = "manifests"
+    if "-o" in sys.argv:
+        dest = sys.argv[sys.argv.index("-o") + 1]
+    elif "--output" in sys.argv:  # pragma: no cover
+        dest = sys.argv[sys.argv.index("--output") + 1]
+
+    _fetch.fetch_all_manifests(dest)
+    raise typer.Exit(0)
+
+
 @app.command()
 def fetch(
-    name: str,
+    name: List[str],
     version: Optional[str] = None,
     include_package_meta: Optional[bool] = typer.Option(
         False,
@@ -337,26 +361,34 @@ def fetch(
         help="If provided, will write manifest to filepath (must end with .yaml, "
         ".json, or .toml). Otherwise, will print to stdout.",
     ),
+    all: Optional[bool] = typer.Option(
+        None,
+        "--all",
+        help="Fetch manifests for ALL known plugins (will be SLOW)",
+        callback=_fetch_all_manifests,
+        is_eager=True,
+    ),
 ):
     """Fetch manifest from remote package.
 
     If an npe2 plugin is detected, the manifest is returned directly, otherwise
     it will be installed into a temporary directory, imported, and discovered.
     """
-    from npe2._fetch import fetch_manifest
+    from npe2 import fetch_manifest
 
     fmt = _check_output(output) if output else format
     kwargs: dict = {"indent": indent}
     if include_package_meta:
         kwargs["exclude"] = set()
 
-    mf = fetch_manifest(name, version=version)
-    manifest_string = getattr(mf, fmt.value)(**kwargs)
+    for n in name:
+        mf = fetch_manifest(n, version=version)
+        manifest_string = getattr(mf, fmt.value)(**kwargs)
 
-    if output:
-        output.write_text(manifest_string)
-    else:
-        _pprint_formatted(manifest_string, fmt)
+        if output:
+            output.write_text(manifest_string)
+        else:
+            _pprint_formatted(manifest_string, fmt)
 
 
 @app.command()
@@ -376,7 +408,7 @@ def convert(
     ),
 ):
     """Convert first generation napari plugin to new (manifest) format."""
-    from ._from_npe1 import convert_repository, manifest_from_npe1
+    from ._inspection._from_npe1 import convert_repository, manifest_from_npe1
 
     try:
         with warnings.catch_warnings(record=True) as w:
@@ -467,5 +499,28 @@ def cache(
                 typer.secho(f"{mf.name}: {mf.package_version}", fg=typer.colors.GREEN)
 
 
+@app.command()
+def compile(
+    src_dir: str,
+    output: Optional[Path] = typer.Option(
+        None,
+        "-o",
+        "--output",
+        exists=False,
+        help="If provided, will write manifest to filepath (must end with .yaml, "
+        ".json, or .toml). Otherwise, will print to stdout.",
+    ),
+    format: Format = typer.Option(
+        "yaml", "-f", "--format", help="Markdown format to use."
+    ),
+):
+    """Compile @npe2.implements contributions to generate a manifest."""
+    from . import _inspection
+
+    manifest = _inspection.compile(src_dir, dest=output)
+    manifest_string = getattr(manifest, format.value)(indent=2)
+    _pprint_formatted(manifest_string, format)
+
+
 def main():
     app()
